[SCM] Samba Shared Repository - branch v3-5-test updated

Karolin Seeger kseeger at samba.org
Wed Jun 1 12:42:46 MDT 2011


The branch, v3-5-test has been updated
       via  a73963dd s3-winbind: BUG 8166 - Don't lockout users when offline.
      from  0ffdf22 Fix bug #7528 - Solaris with NIS autohome.

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=v3-5-test


- Log -----------------------------------------------------------------
commit a73963dd49d33bcfdd5cbc310dad0f895683eadf
Author: Jim McDonough <jmcd at samba.org>
Date:   Wed May 25 10:49:41 2011 -0400

    s3-winbind: BUG 8166 - Don't lockout users when offline.
    
    Windows does not track bad password attempts when offline.  We were locking users out but not honoring the lockout duration.
    
    Autobuild-User: Jim McDonough <jmcd at samba.org>
    Autobuild-Date: Wed May 25 18:11:10 CEST 2011 on sn-devel-104
    (cherry picked from commit b58534f1fca27e3e72f4f4107538ec05734bd42a)

-----------------------------------------------------------------------

Summary of changes:
 source3/winbindd/winbindd_pam.c |    5 ++++-
 1 files changed, 4 insertions(+), 1 deletions(-)


Changeset truncated at 500 lines:

diff --git a/source3/winbindd/winbindd_pam.c b/source3/winbindd/winbindd_pam.c
index aab3b72..df83dc6 100644
--- a/source3/winbindd/winbindd_pam.c
+++ b/source3/winbindd/winbindd_pam.c
@@ -1071,7 +1071,10 @@ static NTSTATUS winbindd_dual_pam_auth_cached(struct winbindd_domain *domain,
 
 	}
 
-	/* User does *NOT* know the correct password, modify info3 accordingly */
+	/* User does *NOT* know the correct password, modify info3 accordingly, but only if online */
+	if (domain->online == false) {
+		goto failed;
+	}
 
 	/* failure of this is not critical */
 	result = get_max_bad_attempts_from_lockout_policy(domain, state->mem_ctx, &max_allowed_bad_attempts);


-- 
Samba Shared Repository


More information about the samba-cvs mailing list